# traefikswarm

Simple command line tool to manage traefik serving a swarm of docker containers

## License

traefikswarm is licensed under the [MIT License](./LICENSE.txt)

Copyright (c) 2020 triaxis s.r.o.
